@@ -8,6 +8,10 @@ class LoyaltyTicketMod(Mod):
     LOYALTY_TICKER_TASK_NAME = "LoyaltyTicketModTask"
 
     async def loaded(self):
+        print('[NOTICE: Loyalty Ticker] Bot currency incrementer for non-bot-owner accounts is not working at the moment '
+              'due to needing a twitch oauth token with `moderator:read:chatters` for each channel. '
+              'For the moment, point incrementing only working for the bot-owner channel.')
+
         if cfg.loyalty_interval == -1:
             print('loyalty_interval in config is -1, loyalty ticker WILL NOT start')
             return
@@ -22,7 +26,7 @@ class LoyaltyTicketMod(Mod):
         print(f'loyalty ticker started!')
         while True:
             for channel in channels.values():
-                for viewer in channel.chatters.all_viewers:
+                for viewer in channel.chatters.viewers:
                     add_balance(channel.name, viewer, cfg.loyalty_amount, commit=False)
                     await sleep(.2)
                 session.commit()
